pub struct AbsDiff<A, B = A>{
pub epsilon: <A as AbsDiffEq<B>>::Epsilon,
}Expand description
The requisite parameters for testing for approximate equality using a absolute difference based comparison.
This is not normally used directly, rather via the
assert_abs_diff_{eq|ne}! and abs_diff_{eq|ne}! macros.
Example
use std::f64;
use approx::AbsDiff;
AbsDiff::default().eq(&1.0, &1.0);
AbsDiff::default().epsilon(f64::EPSILON).eq(&1.0, &1.0);Fields
epsilon: <A as AbsDiffEq<B>>::EpsilonThe tolerance to use when testing values that are close together.
Implementations