pub enum ConcatError<Point>where
Point: Debug,{
DisconnectedParameters(f64, f64),
DisconnectedPoints(Point, Point),
}Expand description
Error for concat curves
Variants
DisconnectedParameters(f64, f64)
Failed to concat curves since the end parameter of the first curve is different form the start parameter of the second curve.
DisconnectedPoints(Point, Point)
Failed to concat curves since the end point of the first curve is different from the start point of the second curve.
Implementations
Sourceimpl<T> ConcatError<T>where
T: Debug,
impl<T> ConcatError<T>where
T: Debug,
Sourcepub fn point_map<U, F>(self, f: F) -> ConcatError<U>
pub fn point_map<U, F>(self, f: F) -> ConcatError<U>
into the